simulate_SSPD3_data: Simulate Split-Split-Plot Experimental Design

View source: R/simulate_data.R

simulate_SSPD3_dataR Documentation

Simulate Split-Split-Plot Experimental Design

Description

simulate_SSPD3_data() creates the data in the SSPD3 example data set. Specifically, it creates data according to the following format:

Usage

simulate_SSPD3_data()

Value

A data.frame with 120 observations on 13 variables:

ID

Observation/split-split-plot identification number, numeric

LOCATION

One of three locations "A", "B", and "C", a blocking variable, categorical

PLOT

Plot identification variable, one for each location and whole plot combination, numeric

REP

Replication number, all 1 as there was no replication, integer

WHOLE_PLOT

Treatment, whether or not the plot was irrigated "IRR_NO" for not irrigated and "IRR_YES" for irrigated, categorical

SPLIT_PLOT

Treatment, fungicide applied to split-plot, 4 fungicides and one control, "Fung1", ..., "Fung4", and "NFung", categorical

SPLIT_SPLIT_PLOT

Treatment, variety of bean seeded in split-split-plot, 4 varieties, "Beans1", ..., "Beans4", categorical

TRT_COMB

Treatments combined over WHOLE_PLOT, SPLIT_PLOT, and SPLIT_SPLIT_PLOT

RESP

Simulated response, not based on a meaningful input values, numeric

LocationF

Factor version of LOCATION

Irrigation

Factor version of WHOLE_PLOT treatment

Fungicide

Factor version of SPLIT_PLOT treatment

Variety

Factor version of SPLIT_SPLIT_PLOT treatment

References

Murillo D, Gezan S (2024). FielDHub: A Shiny App for Design of Experiments in Life Sciences. R package version 1.4.2, https://CRAN.R-project.org/package=FielDHub.

Examples

SSPD3_new <- simulate_SSPD3_data()

modeldiagramR documentation built on April 15, 2026, 5:07 p.m.