| SSPD3 | R Documentation |
The data is simulated using simulate_SSPD3_data()
SSPD3
a data.frame with 120 observations on 13 variables:
Observation/split-split-plot identification number, numeric
One of three locations "A", "B", and "C", a blocking variable, categorical
Plot identification variable, one for each location and whole plot combination, numeric
Replication number, all 1 as there was no replication, integer
Treatment, whether or not the plot was irrigated "IRR_NO" for not irrigated and "IRR_YES" for irrigated, categorical
Treatment, fungicide applied to split-plot, 4 fungicides and one control, "Fung1", ..., "Fung4", and "NFung", categorical
Treatment, variety of bean seeded in split-split-plot, 4 varieties, "Beans1", ..., "Beans4", categorical
Treatments combined over WHOLE_PLOT, SPLIT_PLOT, and SPLIT_SPLIT_PLOT
Simulated response, not based on a meaningful input values, numeric
Factor version of LOCATION
Factor version of WHOLE_PLOT treatment
Factor version of SPLIT_PLOT treatment
Factor version of SPLIT_SPLIT_PLOT treatment
Murillo D, Gezan S (2024). FielDHub: A Shiny App for Design of Experiments in Life Sciences. R package version 1.4.2, https://CRAN.R-project.org/package=FielDHub.
data("SSPD3")
# Simple model for testing
library(nlme)
lme_simple <- lme(RESP ~ Fungicide + Variety, random=~1|LOCATION/WHOLE_PLOT,
data=SSPD3)
model_diagram(lme_simple)
# Intended full model
aov_results <- aov(RESP ~ Irrigation*Fungicide*Variety + Error(LOCATION/WHOLE_PLOT/SPLIT_PLOT),
data=SSPD3)
summary(aov_results)
library(lme4)
library(modeldiagramR)
lmer_results <- lmer(RESP ~ Irrigation*Fungicide*Variety + (1|LOCATION/WHOLE_PLOT/SPLIT_PLOT),
data=SSPD3)
summary(lmer_results)
anova(lmer_results)
model_diagram(lmer_results)
model_diagram(lmer_results, width = 800, height=400, orientation="horizontal",
shiftFixed = 2, shiftRandom = 5, scaleFontSize = 2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.