| md | R Documentation |
Similar to ggplot2::ggplot()'s ggplot2::theme() system, the md_ functions
specify the display of how the node components of the diagram are drawn.
md_color(): border of the node.
md_fill(): fill color of the node.
md_fontColor(): font color of the text in the nodes.
md_color(diagram = "gray25", random = "gray25", fixed = "gray25")
md_fill(diagram = "aliceblue", random = "aliceblue", fixed = "darkseagreen1")
md_fontColor(diagram = "black", random = "black", fixed = "black")
diagram |
Specifies the outline color, fill color, or font color
for the elements in the measurement diagram circles (hierarchical diagram).
Default is |
random |
Specifies the outline color, fill color, or font color
for the elements in the random effect variable boxes.
Default is |
fixed |
Specifies the outline color, fill color, or font color
for the elements in the fixed effect variable boxes.
Default is |
A list object containing color specifications for the border of the nodes.
A list object containing color specifications for the fill of the nodes.
A list object containing color specifications for the font color of the nodes.
# merMod object example
library(lme4)
sleepstudy_lmer <- lmer(Reaction ~ Days + (Days | Subject), sleepstudy)
summary(sleepstudy_lmer)
model_diagram(sleepstudy_lmer,
nodeColors = md_color(diagram="steelblue", random="steelblue", fixed="darkolivegreen1"),
nodeFillColors = md_fill(diagram="aliceblue", random="aliceblue", fixed="darkseagreen1"),
nodeFontColors = md_fontColor(diagram="black", random="blue", fixed="black"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.