View source: R/simulate_data.R
| simulate_SSPD3_data | R Documentation |
simulate_SSPD3_data() creates the data in the SSPD3 example data set.
Specifically, it creates data according to the following format:
simulate_SSPD3_data()
A data.frame with 120 observations on 13 variables:
Observation/split-split-plot identification number, numeric
One of three locations "A", "B", and "C", a blocking variable, categorical
Plot identification variable, one for each location and whole plot combination, numeric
Replication number, all 1 as there was no replication, integer
Treatment, whether or not the plot was irrigated "IRR_NO" for not irrigated and "IRR_YES" for irrigated, categorical
Treatment, fungicide applied to split-plot, 4 fungicides and one control, "Fung1", ..., "Fung4", and "NFung", categorical
Treatment, variety of bean seeded in split-split-plot, 4 varieties, "Beans1", ..., "Beans4", categorical
Treatments combined over WHOLE_PLOT, SPLIT_PLOT, and SPLIT_SPLIT_PLOT
Simulated response, not based on a meaningful input values, numeric
Factor version of LOCATION
Factor version of WHOLE_PLOT treatment
Factor version of SPLIT_PLOT treatment
Factor version of SPLIT_SPLIT_PLOT treatment
Murillo D, Gezan S (2024). FielDHub: A Shiny App for Design of Experiments in Life Sciences. R package version 1.4.2, https://CRAN.R-project.org/package=FielDHub.
SSPD3_new <- simulate_SSPD3_data()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.